<%! from crab.util.web import abbr %> <%inherit file="base.html"/> <%block name="links"> ${info['host'] | h} ${info['user'] | h} % if info['crabid'] is not None: ${info['crabid'] | h} % else: ${info['command'] | abbr} % endif configuration

## Job Configuration

% if config is None:

### Add New Job Configuration

% else:

### Edit Job Configuration

% endif

Any parameter which is left blank here will use the default value.

1. Grace period minutes
2. Time-out minutes

These patterns (if set) will be matched against the job's output.

1. Success pattern
2. Warning pattern
3. Failure pattern

Here you can enter any notes about this job.

1. Notes % if config is not None and config['note'] is not None: ${config['note'] | h} % else: % endif

This setting requests that the job not be run.

1. Inhibit execution % if config is not None and config['inhibit']: % else: % endif

% if config is None: % if orphan:

### Re-link Orphaned Job Configuration

There are orphaned configurations, relating to deleted jobs.

If this job is the continuation of one which has been deleted, its configuration can be transferred by selecting it for re-linking.

% endif % endif

## Job Control

% if info['deleted'] is None: Delete % else: Undelete % endif job.

### Change Job ID

1. New Job ID